@@ -2,13 +2,30 @@ import numpy as np
 import math
 
 from .query import centroid, distances_plane_to_points
-from .geometry import Plane, Vector, Point, VectorLike
-from typing import Sequence, Union, Dict, Tuple
+from .geometry import MultipleVectorLike, Plane, Vector, Point
+from typing import Union, Dict, Tuple, overload, Any
+try:
+    from typing import Literal
+except ImportError:
+    from typing_extensions import Literal
+
+@overload
+def fit_plane(
+    points: MultipleVectorLike, return_fit_props: Literal[False] = False
+) -> Plane:
+    ...
+
+
+@overload
+def fit_plane(
+    points: MultipleVectorLike, return_fit_props: Literal[True] = True
+) -> Tuple[Plane, Dict[str, Any]]:
+    ...
 
 
 def fit_plane(
-    points: Sequence[VectorLike], return_fit_props=False
-) -> Union[Plane, Tuple[Plane, Dict]]:
+    points: MultipleVectorLike, return_fit_props: bool = False
+) -> Union[Plane, Tuple[Plane, Dict[str, Any]]]:
     """Fit plane to points
 
     Args:
